package com.ruoyi.ems.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.AdmEmsElecBoxIndex;
import com.ruoyi.ems.service.IAdmEmsElecBoxIndexService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 动力箱指标Controller
 *
 * @author ruoyi
 * @date 2024-09-03
 */
@RestController
@RequestMapping("/powerBoxIndex")
public class AdmEmsElecBoxIndexController extends BaseController {
    @Autowired
    private IAdmEmsElecBoxIndexService admEmsElecBoxIndexService;

    /**
     * 查询动力箱指标列表
     */
    @GetMapping("/list")
    public TableDataInfo list(AdmEmsElecBoxIndex admEmsElecBoxIndex) {
        startPage();
        List<AdmEmsElecBoxIndex> list = admEmsElecBoxIndexService.selectAdmEmsElecBoxIndexList(admEmsElecBoxIndex);
        return getDataTable(list);
    }

    /**
     * 导出动力箱指标列表
     */
    @Log(title = "动力箱指标", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AdmEmsElecBoxIndex admEmsElecBoxIndex) {
        List<AdmEmsElecBoxIndex> list = admEmsElecBoxIndexService.selectAdmEmsElecBoxIndexList(admEmsElecBoxIndex);
        ExcelUtil<AdmEmsElecBoxIndex> util = new ExcelUtil<AdmEmsElecBoxIndex>(AdmEmsElecBoxIndex.class);
        util.exportExcel(response, list, "动力箱指标数据");
    }

    /**
     * 获取动力箱指标详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(admEmsElecBoxIndexService.selectAdmEmsElecBoxIndexById(id));
    }

    /**
     * 获取动力箱指标详细信息
     */
    @GetMapping(value = "/latest/{boxCode}")
    public AjaxResult getLatestIndexByBoxCode(@PathVariable("boxCode") String boxCode) {
        return success(admEmsElecBoxIndexService.selectAdmEmsElecBoxIndexByBoxCode(boxCode));
    }

    /**
     * 新增动力箱指标
     */
    @Log(title = "动力箱指标", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AdmEmsElecBoxIndex admEmsElecBoxIndex) {
        return toAjax(admEmsElecBoxIndexService.insertAdmEmsElecBoxIndex(admEmsElecBoxIndex));
    }

    /**
     * 修改动力箱指标
     */
    @Log(title = "动力箱指标", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AdmEmsElecBoxIndex admEmsElecBoxIndex) {
        return toAjax(admEmsElecBoxIndexService.updateAdmEmsElecBoxIndex(admEmsElecBoxIndex));
    }

    /**
     * 删除动力箱指标
     */
    @Log(title = "动力箱指标", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(admEmsElecBoxIndexService.deleteAdmEmsElecBoxIndexByIds(ids));
    }
}
